@@ -83,7 +83,26 @@ class Translator:
     def translate_to(self, vo, fmt):
         """translate vrs object `vo` to named format `fmt`"""
         t = self.to_translators[fmt]
-        return t(self, vo)
+        return t(self, self.ensure_allele_is_latest_model(vo))
+
+    def ensure_allele_is_latest_model(self, allele):
+        """
+        Change deprecated models:
+        SequenceState -> LiteralSequenceExpression
+        SimpleInterval -> SequenceInterval
+        """
+        if allele.state.type == "SequenceState":
+            allele.state = models.LiteralSequenceExpression(
+                type="LiteralSequenceExpression",
+                sequence=allele.state.sequence,
+            )
+        if allele.location.interval.type == "SimpleInterval":
+            allele.location.interval = models.SequenceInterval(
+                type="SequenceInterval",
+                start=models.Number(value=allele.location.interval.start, type="Number"),
+                end=models.Number(value=allele.location.interval.end, type="Number"),
+            )
+        return allele
 
 
     ############################################################################
@@ -121,11 +140,14 @@ class Translator:
         end = start + len(ref)
         ins_seq = alt
 
-        interval = models.SequenceInterval(start=models.Number(value=start),
-                                           end=models.Number(value=end))
-        location = models.Location(sequence_id=sequence_id, interval=interval)
-        sstate = models.LiteralSequenceExpression(sequence=ins_seq)
-        allele = models.Allele(location=location, state=sstate)
+        interval = models.SequenceInterval(start=models.Number(value=start, type="Number"),
+                                           end=models.Number(value=end, type="Number"),
+                                           type="SequenceInterval")
+        location = models.SequenceLocation(sequence_id=sequence_id,
+                                           interval=interval, type="SequenceLocation")
+        state = models.LiteralSequenceExpression(sequence=ins_seq,
+                                                  type="LiteralSequenceExpression")
+        allele = models.Allele(location=location, state=state, type="Allele")
         allele = self._post_process_imported_allele(allele)
         return allele
 
@@ -162,11 +184,12 @@ class Translator:
         end = start + len(ref)
         ins_seq = alt
 
-        interval = models.SequenceInterval(start=models.Number(value=start),
-                                           end=models.Number(value=end))
-        location = models.Location(sequence_id=sequence_id, interval=interval)
-        sstate = models.LiteralSequenceExpression(sequence=ins_seq)
-        allele = models.Allele(location=location, state=sstate)
+        interval = models.SequenceInterval(start=models.Number(value=start, type="Number"),
+                                           end=models.Number(value=end, type="Number"),
+                                           type="SequenceInterval")
+        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval, type="SequenceLocation")
+        sstate = models.LiteralSequenceExpression(sequence=ins_seq, type="LiteralSequenceExpression")
+        allele = models.Allele(location=location, state=sstate, type="Allele")
         allele = self._post_process_imported_allele(allele)
         return allele
 
@@ -207,13 +230,15 @@ class Translator:
 
         if sv.posedit.edit.type == "ins":
             interval = models.SequenceInterval(
-                start=models.Number(value=sv.posedit.pos.start.base),
-                end=models.Number(value=sv.posedit.pos.start.base))
+                start=models.Number(value=sv.posedit.pos.start.base, type="Number"),
+                end=models.Number(value=sv.posedit.pos.start.base, type="Number"),
+                type="SequenceInterval")
             state = sv.posedit.edit.alt
         elif sv.posedit.edit.type in ("sub", "del", "delins", "identity"):
             interval = models.SequenceInterval(
-                start=models.Number(value=sv.posedit.pos.start.base - 1),
-                end=models.Number(value=sv.posedit.pos.end.base))
+                start=models.Number(value=sv.posedit.pos.start.base - 1, type="Number"),
+                end=models.Number(value=sv.posedit.pos.end.base, type="Number"),
+                type="SequenceInterval")
             if sv.posedit.edit.type == "identity":
                 state = self.data_proxy.get_sequence(sv.ac,
                                                      sv.posedit.pos.start.base - 1,
@@ -223,8 +248,9 @@ class Translator:
         elif sv.posedit.edit.type == "dup":
 
             interval = models.SequenceInterval(
-                start=models.Number(value=sv.posedit.pos.start.base - 1),
-                end=models.Number(value=sv.posedit.pos.end.base))
+                start=models.Number(value=sv.posedit.pos.start.base - 1, type="Number"),
+                end=models.Number(value=sv.posedit.pos.end.base, type="Number"),
+                type="SequenceInterval")
 
             ref = self.data_proxy.get_sequence(sv.ac,
                                                sv.posedit.pos.start.base - 1,
@@ -233,9 +259,9 @@ class Translator:
         else:
             raise ValueError(f"HGVS variant type {sv.posedit.edit.type} is unsupported")
 
-        location = models.Location(sequence_id=sequence_id, interval=interval)
-        sstate = models.LiteralSequenceExpression(sequence=state)
-        allele = models.Allele(location=location, state=sstate)
+        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval, type="SequenceLocation")
+        sstate = models.LiteralSequenceExpression(sequence=state, type="LiteralSequenceExpression")
+        allele = models.Allele(location=location, state=sstate, type="Allele", )
         allele = self._post_process_imported_allele(allele)
         return allele
 
@@ -276,11 +302,12 @@ class Translator:
         end = start + del_len
         ins_seq = g["ins_seq"]
 
-        interval = models.SequenceInterval(start=models.Number(value=start),
-                                           end=models.Number(value=end))
-        location = models.Location(sequence_id=sequence_id, interval=interval)
-        sstate = models.LiteralSequenceExpression(sequence=ins_seq)
-        allele = models.Allele(location=location, state=sstate)
+        interval = models.SequenceInterval(start=models.Number(value=start, type="Number"),
+                                           end=models.Number(value=end, type="Number"),
+                                           type="SequenceInterval")
+        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval, type="SequenceLocation")
+        sstate = models.LiteralSequenceExpression(sequence=ins_seq, type="LiteralSequenceExpression")
+        allele = models.Allele(location=location, state=sstate, type="Allele")
         allele = self._post_process_imported_allele(allele)
         return allele
 
@@ -334,10 +361,8 @@ class Translator:
                 return "g"
             return None
 
-        if (type(vo).__name__ != "Allele"
-            or type(vo.location).__name__ != "SequenceLocation"
-            or type(vo.state).__name__ != "LiteralSequenceExpression"):
-            raise ValueError(f"_to_hgvs requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
+        if not self.is_valid_allele(vo):
+            raise ValueError("_to_hgvs requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
 
         sequence_id = str(vo.location.sequence_id)
         aliases = self.data_proxy.translate_sequence_identifier(sequence_id, namespace)
@@ -355,8 +380,7 @@ class Translator:
             # ival = hgvs.location.Interval(start=start, end=end)
             # edit = hgvs.edit.AARefAlt(ref=None, alt=vo.state.sequence)
         else:                   # pylint: disable=no-else-raise
-            start = vo.location.interval.start.value
-            end = vo.location.interval.end.value
+            start, end = vo.location.interval.start.value, vo.location.interval.end.value
             # ib: 0 1 2 3 4 5
             #  h:  1 2 3 4 5
             if start == end:    # insert: hgvs uses *exclusive coords*
@@ -405,6 +429,7 @@ class Translator:
 
         return list(set(hgvs_exprs))
 
+
     def _to_spdi(self, vo, namespace="refseq"):
         """generates a *list* of SPDI expressions for VRS Allele.
 
@@ -423,23 +448,24 @@ class Translator:
         is expected to be normalized per VRS spec.
 
         """
-
-        if (type(vo).__name__ != "Allele"
-            or type(vo.location).__name__ != "SequenceLocation"
-            or type(vo.state).__name__ != "LiteralSequenceExpression"):
-            raise ValueError(f"_to_hgvs requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
+        if not self.is_valid_allele(vo):
+            raise ValueError("_to_spdi requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
 
         sequence_id = str(vo.location.sequence_id)
         aliases = self.data_proxy.translate_sequence_identifier(sequence_id, namespace)
         aliases = [a.split(":")[1] for a in aliases]
-
-        start = vo.location.interval.start.value
-        end = vo.location.interval.end.value
+        start, end = vo.location.interval.start.value, vo.location.interval.end.value
         spdi_tail = f":{start}:{end-start}:{vo.state.sequence}"
         spdis = [a + spdi_tail for a in aliases]
         return spdis
 
 
+    def is_valid_allele(self, vo):
+        return (vo.type == "Allele"
+                and vo.location.type == "SequenceLocation"
+                and vo.state.type == "LiteralSequenceExpression")
+
+
     @lazy_property
     def _hgvs_parser(self):
         """instantiates and returns an hgvs parser instance"""
